#!/bin/bash
# Intel(R) Application Debugger for Linux
# Copyright (C) 2000-2012 Intel Corporation. All rights reserved.

#set -x

MIC_LAUNCHER=micnativeloadex
MPSS_VERSION=`rpm -q mpss-sdk-k1om --queryformat '%{version}'`
SYSROOTS=/opt/mpss/$MPSS_VERSION/sysroots
K1OM_TUPLE=k1om-mpss-linux
CROSS_TUPLE=x86_64-mpsssdk-linux

SDK_SYSROOT=$SYSROOTS/$CROSS_TUPLE

if [ $# -lt 2 ] ; then
    echo "Usage: $0 <MIC card number> <PID of MIC process> [<GDB options>]"
    exit 1
fi

card_num=$1
shift

pid=$1
shift

if [ -z "$MIC_SYSROOT" ] ; then
    MIC_SYSROOT=$SYSROOTS/$K1OM_TUPLE
fi

if [ -z "$GDB_CROSS" ] ; then
    GDB_CROSS=$SDK_SYSROOT/usr/bin/$K1OM_TUPLE/$K1OM_TUPLE-gdb
fi

if [ -z "$GDBSERVER_MIC" ] ; then
    GDBSERVER_MIC=$MIC_SYSROOT/usr/bin/gdbserver
fi

sysfs=`mount | sed -ne 's/.* on \(.*\) type sysfs.*/\1/p'`

if [ ! -d "$sysfs/class/mic" ] ; then
    echo "$sysfs/class/mic is not a directory!"
    exit 2
fi

card_dir=$sysfs/class/mic/mic$card_num

if [ ! -d $card_dir ] ; then 
    echo "Sysfs directory for the card ($card_dir) not found!"
    exit 3
fi

card_status=`cat $card_dir/state`

if [ $card_status == "online" ]; then
    if [ -z "${SINK_LD_LIBRARY_PATH}" ] ; then
        SINK_LD_LIBRARY_PATH="$MIC_SYSROOT/lib64:$MIC_SYSROOT/usr/lib64"; export SINK_LD_LIBRARY_PATH
    else
        SINK_LD_LIBRARY_PATH="${SINK_LD_LIBRARY_PATH}:$MIC_SYSROOT/lib64:$MIC_SYSROOT/usr/lib64"; export SINK_LD_LIBRARY_PATH
    fi

    if [ $pid == "0" ] ; then
        # there's no process with a PID of zero: this is just for starting in "manual mode"
        gdbserver_opts="--multi :$MIC_GDBSERVER_PORT"
    else
        # the normal case: called from MPM
        gdbserver_opts="--once --attach :$MIC_GDBSERVER_PORT $pid"
    fi

    ($MIC_LAUNCHER $GDBSERVER_MIC -d $card_num -a "$gdbserver_opts" &> /dev/null) &

    $GDB_CROSS $@
else
    echo "MIC card $card_num is not online!"
    exit 4
fi

exit 0
